package com.cultural.heritage.model.dto.snapshot;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;

/**
 * 服装信息快照
 */
@Data
@Schema(description = "服装信息快照", requiredProperties = {"id", "name", "categoryId", "price", "period", "image"})
public class ClothesSnapshot implements Serializable {


    /**
     * 编号
     */
    @Schema(description = "服装编号", example = "1")
    private Long id;

    /**
     * 服装名称
     */
    @Schema(description = "服装名称", example = "夏季连衣裙")
    private String name;

    /**
     * 类别id
     */
    @Schema(description = "服装类别ID", example = "2")
    private Long categoryId;

    /**
     * 价格/天
     */
    @Schema(description = "租赁价格（每一天）", example = "100.00")
    private BigDecimal price;

    /**
     * 最大租赁天数
     */
    @Schema(description = "最大租赁天数", example = "7")
    private Integer period;

    /**
     * 服装图片
     */
    @Schema(description = "服装图片URL", example = "http://example.com/images/dress.jpg")
    private String image;


    @Serial
    private static final long serialVersionUID = 1L;

}
