package com.cultural.heritage.service.clothes.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.constant.CommonConstant;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.exception.ThrowUtils;
import com.cultural.heritage.mapper.ClothesMapper;
import com.cultural.heritage.model.dto.clothes.ClothesQueryRequest;
import com.cultural.heritage.model.entity.Clothes;
import com.cultural.heritage.model.vo.clothes.ClothesVO;
import com.cultural.heritage.service.clothes.ClothesService;
import com.cultural.heritage.service.common.CommonService;
import com.cultural.heritage.utils.DecoderUtils;
import com.cultural.heritage.utils.SqlUtils;
import jakarta.annotation.Resource;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;

@Service
public class ClothesServiceImpl extends ServiceImpl<ClothesMapper, Clothes> implements ClothesService {


    @Resource
    private CommonService commonService;


    /**
     * 校验
     */
    @Override
    public void validClothes(Clothes clothes, boolean update) {
        Long id = clothes.getId();
        String name = clothes.getName();
        Long categoryId = clothes.getCategoryId();
        BigDecimal price = clothes.getPrice();
        Integer period = clothes.getPeriod();

        if (update) {
            if (id == null) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "参数id错误");
            }
        }
        if (StringUtils.isBlank(name)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "服装名称不能为空");
        }
        if (categoryId == null || categoryId <= 0) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "服装类别不能为空");
        }
        if (price == null || price.compareTo(BigDecimal.ZERO) <= 0) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "价格必须大于零");
        }
        if (period == null || period <= 0) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "租赁天数必须大于零");
        }
    }


    /**
     * 获取查询条件
     */
    @Override
    public QueryWrapper<Clothes> getQueryWrapper(ClothesQueryRequest clothesQueryRequest) {

        Long id = clothesQueryRequest.getId();
        String name = clothesQueryRequest.getName();
        Long categoryId = clothesQueryRequest.getCategoryId();
        Integer isShelves = clothesQueryRequest.getIsShelves();
        String sortField = clothesQueryRequest.getSortField();
        String sortOrder = clothesQueryRequest.getSortOrder();

        QueryWrapper<Clothes> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(id != null, "id", id);
        queryWrapper.like(StringUtils.isNotBlank(name), "name", name);
        queryWrapper.eq(categoryId != null, "categoryId", categoryId);
        queryWrapper.eq(isShelves != null, "isShelves", isShelves);

        // 根据排序字段和排序顺序进行排序
        queryWrapper.orderBy(SqlUtils.validSortField(sortField),
                sortOrder.equals(CommonConstant.SORT_ORDER_ASC),
                sortField);

        return queryWrapper;
    }


    /**
     * 根据服装id查询服装信息
     */
    public ClothesVO getClothesById(Long id) {
        if (id == null || id <= 0) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        Clothes clothes = this.getById(id);
        ThrowUtils.throwIf(clothes == null, ErrorCode.OPERATION_ERROR, "服装不存在");
        // 处理富文本字段
        if (StringUtils.isNotBlank(clothes.getRichText())) clothes.setRichText(DecoderUtils.decodeText(clothes.getRichText()));
        // 转换为VO对象
        return commonService.copyProperties(clothes, ClothesVO.class);
    }
}
